<?php
/**
 * Plugin Name: Event Tickets: Shortcode
 * Description: Hides the Ticket/RSVP form and makes them display when you insert the shortcode [event_tickets_forms_display]
 * Version: 2016-08-11
 * Author: Modern Tribe, Inc.
 * Author URI: http://m.tri.be/1x
 * License: GPLv2 or later
 */
defined( 'WPINC' ) or die;

// The snippet framework files
require_once dirname( __FILE__ ) . '/tribe-snippet-framework/src/Tribe/Snippet.php';
require_once dirname( __FILE__ ) . '/tribe-snippet-framework/src/Tribe/Settings_Helper.php';
require_once dirname( __FILE__ ) . '/tribe-snippet-framework/src/Tribe/View_Helper.php';
require_once dirname( __FILE__ ) . '/tribe-snippet-framework/src/functions/general.php';


Class Tribe__Snippet__Tickets__Shortcode extends Tribe__Snippet {

	/**
	 * List of plugins required for this snippet to run
	 *
	 * Note: Snippet will not run unless all of these are activated, delete any unnecessary ones
	 */
	protected $plugins_required = array(
		'Event Tickets',
	);

	/**
	 * The base plugin file - usually set this to __FILE__
	 */
	protected $snippet_file = __FILE__;

	protected $load_priority = 50;

	protected $et_classes = array(
		'Easy_Digital_Downloads' =>     'Tribe__Tickets_Plus__Commerce__EDD__Main',
		'ShoppVersion' =>               'Tribe__Tickets_Plus__Commerce__Shopp__Main',
		'WP_eCommerce' =>               'Tribe__Tickets_Plus__Commerce__WPEC__Main',
		'Woocommerce' =>                'Tribe__Tickets_Plus__Commerce__WooCommerce__Main',
		'Tribe__Tickets__Tickets' =>    'Tribe__Tickets__RSVP',
	);

	protected $et_event_hook = 'tribe_events_single_event_after_the_meta';
	protected $et_event_hook_function = 'front_end_tickets_form';
	protected $et_post_hook = 'the_content';
	protected $et_post_hook_function = 'front_end_tickets_form_in_content';

	public $et_instances;

	public $et_view_instance;

	public function snippet_init () {
		// Exit if the necessary class does not exist
		if( ! class_exists( 'Tribe__Tickets__Tickets_View' ) ) return;

		$this->et_instances = $this->get_et_instances();
		add_shortcode( 'event_tickets_forms_display', array( $this, 'output_shortcode' ) );
		$this->move_event_tickets_forms( 'event_tickets_forms_display' );
		$this->move_post_tickets_forms( 'event_tickets_forms_display' );
	}

	public function output_shortcode( $atts ) {
		ob_start();
		do_action( 'event_tickets_forms_display' );
		$output = ob_get_clean();

		return $output;
	}

	public function get_et_instances() {
		$instances = array();

		foreach ( $this->et_classes as  $ecommerce_class => $ticket_class) {
			if ( ! class_exists( $ecommerce_class ) || ! class_exists( $ticket_class ) ) continue;
			$instances[] = $ticket_class::get_instance();
		}

		$this->et_view_instance = Tribe__Tickets__Tickets_View::instance();

		return $instances;
	}

	public function move_event_tickets_forms( $action_hook, $priority = 10 ) {
		$this->remove_event_tickets_forms();

		add_action(
			$action_hook,
			array( $this->et_view_instance, 'inject_link_template' ),
			$priority
		);

		foreach ( $this->et_instances as $instance ) {
			add_action(
				$action_hook,
				array( $instance, $this->et_event_hook_function),
				$priority
			);
		}
	}

	public function move_post_tickets_forms( $action_hook, $priority = 10 ) {
		$this->remove_post_tickets_forms();

		add_action(
			$action_hook,
			array( $this->et_view_instance, 'inject_link_template_the_content' ),
			$priority
		);

		foreach ( $this->et_instances as $instance ) {
			add_action(
				$action_hook,
				array( $instance, $this->et_post_hook_function),
				$priority
			);
		}
	}

	public function remove_event_tickets_forms() {
		$link_template_function = array( $this->et_view_instance, 'inject_link_template' );

		if ( has_action ( $this->et_event_hook, $link_template_function ) )
			remove_action( $this->et_event_hook, $link_template_function, 4 );

		foreach ( $this->et_instances as $instance ) {
			$instance_function = array( $instance, $this->et_event_hook_function );
			if ( has_action ( $this->et_event_hook, $instance_function ) )
				remove_action( $this->et_event_hook, $instance_function, 5 );
		}
	}

	public function remove_post_tickets_forms() {
		$link_template_function = array( $this->et_view_instance, 'inject_link_template_the_content' );

		if ( has_filter ( $this->et_post_hook, $link_template_function ) )
			remove_filter( $this->et_post_hook, $link_template_function, 9 );

		foreach ( $this->et_instances as $instance ) {
			$instance_function = array( $instance, $this->et_post_hook_function );
			if ( has_filter ( $this->et_post_hook, $instance_function ) )
				remove_filter( $this->et_post_hook, $instance_function );
		}
	}

}

new Tribe__Snippet__Tickets__Shortcode();